import openpyxl
from jinja2 import Environment, FileSystemLoader
import os

folder_path = "config"
if not os.path.exists(folder_path):
    os.makedirs(folder_path)
    print(f"文件夹 {folder_path} 已创建。")
else:
    print(f"文件夹 {folder_path} 已存在。")

# 读取 Excel 文件
wb = openpyxl.load_workbook('5gc_config.xlsx')
sheet = wb.active

# 获取参数名称（第一行）
param_names = [cell.value for cell in sheet[1]]

# 设置 Jinja2 模板环境
env = Environment(loader=FileSystemLoader('.'))
amf_template = env.get_template('template/amf.template')
smf_template = env.get_template('template/smf.template')
upf_template = env.get_template('template/upf.template')

# 遍历 Excel 表中的每一行（除第一行）并生成配置文件
for row_idx, row in enumerate(sheet.iter_rows(min_row=2, values_only=True)):
    config_data = dict(zip(param_names, row))
    with open(f'{folder_path}/amf_{row_idx}.conf', 'w') as f:
        f.write(amf_template.render(**config_data))
    with open(f'{folder_path}/smf_{row_idx}.conf', 'w') as f:
        f.write(smf_template.render(**config_data))
    with open(f'{folder_path}/upf_{row_idx}.conf', 'w') as f:
        f.write(upf_template.render(**config_data))