#!/bin/bash

set -o pipefail

################################
# include helper functions
################################
THIS_SCRIPT_PATH=$(dirname $(readlink -f $0))
source ${THIS_SCRIPT_PATH}/script_helper

REMOTE_URL="www.opensource5g.org:18083"
DOCKER_CONFIG="/etc/docker/daemon.json"
docker_config_presence=0

if [ -f "$DOCKER_CONFIG" ]; then
    docker_config_presence=1
    mv $DOCKER_CONFIG $DOCKER_CONFIG.back
fi
cat > $DOCKER_CONFIG << EOF
{
    "insecure-registries": ["$REMOTE_URL"]
}
EOF

systemctl daemon-reload
systemctl restart docker

if [[ "$(docker images -q mysql:latest> /dev/null)" != "" ]]; then
    echo_success "mysql:latest already exists!"
else
    docker pull $REMOTE_URL/diankeyuan/aarch64/mysql:latest
    docker tag $REMOTE_URL/diankeyuan/aarch64/mysql:latest mysql:latest
    docker rmi $REMOTE_URL/diankeyuan/aarch64/mysql:latest
    echo_success "mysql:latest is successfully pulled!"
fi

if [[ "$(docker images -q phpmyadmin:latest 2> /dev/null)" != "" ]]; then
    echo_success "phpmyadmin:latest already exists!"
else
    docker pull $REMOTE_URL/diankeyuan/aarch64/phpmyadmin:latest
    docker tag $REMOTE_URL/diankeyuan/aarch64/phpmyadmin:latest phpmyadmin:latest
    docker rmi $REMOTE_URL/diankeyuan/aarch64/phpmyadmin:latest
    echo_success "phpmyadmin:latest is successfully pulled!"
fi

if [[ "$(docker images -q openxg-amf:v1.5.3 2> /dev/null)" != "" ]]; then
    echo_success "openxg-amf:v1.5.3 already exists!"
else
    docker pull $REMOTE_URL/diankeyuan/aarch64/openxg-amf:v1.5.3
    docker tag $REMOTE_URL/diankeyuan/aarch64/openxg-amf:v1.5.3 openxg-amf:v1.5.3
    docker rmi $REMOTE_URL/diankeyuan/aarch64/openxg-amf:v1.5.3
    echo_success "openxg-amf:v1.5.3 is successfully pulled!"
fi

if [[ "$(docker images -q openxg-smf:v1.5.3 2> /dev/null)" != "" ]]; then
    echo_success "openxg-smf:v1.5.3 already exists!"
else
    docker pull $REMOTE_URL/diankeyuan/aarch64/openxg-smf:v1.5.3
    docker tag $REMOTE_URL/diankeyuan/aarch64/openxg-smf:v1.5.3 openxg-smf:v1.5.3
    docker rmi $REMOTE_URL/diankeyuan/aarch64/openxg-smf:v1.5.3
    echo_success "openxg-smf:v1.5.3 is successfully pulled!"
fi

if [[ "$(docker images -q openxg-upf:v1.5.3 2> /dev/null)" != "" ]]; then
    echo_success "openxg-upf:v1.5.3 already exists!"
else
    docker pull $REMOTE_URL/diankeyuan/aarch64/openxg-upf:v1.5.3
    docker tag $REMOTE_URL/diankeyuan/aarch64/openxg-upf:v1.5.3 openxg-upf:v1.5.3
    docker rmi $REMOTE_URL/diankeyuan/aarch64/openxg-upf:v1.5.3
    echo_success "openxg-upf:v1.5.3 is successfully pulled!"
fi

if [[ "$(docker images -q openxg-ueransim:v1.5.3 2> /dev/null)" != "" ]]; then
    echo_success "openxg-ueransim:v1.5.3 already exists!"
else
    docker pull $REMOTE_URL/diankeyuan/aarch64/ueransim:v1.5.3
    docker tag $REMOTE_URL/diankeyuan/aarch64/ueransim:v1.5.3 openxg-ueransim:v1.5.3
    docker rmi $REMOTE_URL/diankeyuan/aarch64/ueransim:v1.5.3
    echo_success "openxg-ueransim:v1.5.3 is successfully pulled!"
fi

rm $DOCKER_CONFIG
if [ $docker_config_presence -eq 1 ]; then
    mv $DOCKER_CONFIG.back $DOCKER_CONFIG
fi
systemctl daemon-reload
systemctl restart docker

